@@ -17,8 +17,12 @@
 
 #include "plugin.h"
 
-Plugin::Plugin()
-    : m_enabled( false )
+#include "tokenhelpdialog.h"
+
+const QString Plugin::S_TOKEN_SEPARATOR = TokenHelpDialog::S_TOKEN_SEPARATOR;
+
+Plugin::Plugin( PluginLoader* loader )
+    : m_pluginLoader( loader ), m_enabled( false )
 {
 }
 
@@ -26,3 +30,23 @@ Plugin::~Plugin()
 {
 
 }
+
+void Plugin::loadConfig( KConfigGroup & )
+{
+    /* Do nothing by default */
+}
+
+void Plugin::saveConfig( KConfigGroup & ) const
+{
+    /* Do nothing by default */
+}
+
+QString Plugin::createHelpEntry( const QString & token, const QString & help )
+{
+  QString cmd = "[";
+  cmd = cmd + token + "]" + Plugin::S_TOKEN_SEPARATOR;
+  cmd = cmd + help;
+
+  return cmd;
+}
+
