@@ -48,6 +48,8 @@ class TokenHelpDialog : public KDialog {
      */
     void add( const QString & headline, const QStringList & commands, const QPixmap & icon, bool first = false );
 
+    static const QString S_TOKEN_SEPARATOR; ///< Separator between token and help
+
  public slots:
      int exec();
 
@@ -63,6 +65,25 @@ class TokenHelpDialog : public KDialog {
 
  private:
     void loadConfig();
+    
+    /**
+     * Select a category by its name.
+     * \param category user visible name of a category
+     */
+    void selectCategory( const QString & category );
+    
+    /**
+     * Add all tokens stored in the list
+     * m_recent to the list of tokens and to categories.
+     */
+    void addRecentTokens();
+
+    /**
+     * Add a token to the list of recent tokens.
+     * \param token the token itself
+     * \param help the help string for the token
+     */
+    void addToRecentTokens( const QString & token, const QString & help );
 
  private:
     KRenameUnformattedWrappedModel* m_model;
@@ -75,6 +96,11 @@ class TokenHelpDialog : public KDialog {
     QMap<QString,QStringList> m_map;
 
     QString             m_first;
+
+    QString             m_lastSelected;
+    QStringList         m_recent;
+
+    static const int    S_MAX_RECENT; ///< Maximum number of recent tokens
 };
 
 #endif // _TOKEN_HELP_DIALOG_H_
